@@ -1,12 +1,13 @@
-moonscript = require('moonscript')
+local moonscript = require('moonscript')
 moonscript.errors = require "moonscript.errors"
-moon = require('moon')
 local line_tables = require "moonscript.line_tables"
 
-lua_loadfile = loadfile
-lua_pcall = pcall
+local lua_loadfile = loadfile
+local lua_pcall = pcall
 
-loadfile = function(filename, mode, env)
+_G.moon = require('moon')
+
+_G.loadfile = function(filename, mode, env)
   filename = tostring(filename)
   if (filename:match('%.moon$')) then
     local status, ret = moonscript.loadfile(filename)
@@ -20,8 +21,9 @@ loadfile = function(filename, mode, env)
 end
 
 local function error_rewriter(err)
+  if type(err) ~= 'string' then return err end
   if not err:match('%.moon') then return err end
-  moon_file = err:match('^%[string "([^"]+%.moon)"%]')
+  local moon_file = err:match('^%[string "([^"]+%.moon)"%]') or err:match('^([^%s]+%.moon)')
   if not moon_file then return err end
 
   -- if the file hasn't been compiled yet we do it first for error rewriting to work
@@ -32,9 +34,13 @@ local function error_rewriter(err)
   local trace = debug.traceback("", 2)
   trace = trace:match('%s*(.+)%s*$')
   local rewritten = moonscript.errors.rewrite_traceback(trace, err)
+  if howl.sys.env.HOWL_PRINT_TRACEBACKS then
+    print(rewritten)
+  end
   return rewritten or err
 end
 
-pcall = function(f, ...)
-  return xpcall(f, error_rewriter, ...)
+_G.pcall = function(f, ...)
+  local rets = table.pack(xpcall(f, error_rewriter, ...))
+  return table.unpack(rets, 1, rets.n)
 end
